--------------------------------------------------------------------------------
-- Code developed by Generis Technology Limited
--
-- Product Name: B-Smart
--
-- Component Name: Job Manager
--
-- Description: Script to create Cross Reference standing data.
--
-- Amendment History:                   Date        Author            Vers
-- ------------------                   ---------   -------           -----
-- B-Smart Initial Release              29-NOV-01   R Maas            0.1.0
-- Change for release 1.0.30            01-MAR-02   R Maas            1.0.30
-- Tidied up script                     08-MAR-02   R Maas            1.0.31
-- Changed JOB_REQUESTER to REQUESTER   08-MAR-02   R Maas            1.0.32
-- Add new code for CONTACT_METHOD_CODE 13-MAR-02   R Maas            1.0.33
-- Add generis timestamp                25-MAR-02   R Maas            1.0.34
-- Changes for release 1.0.60           08-APR-02   R Maas            1.0.60
-- Removed sup from contact_role_code   30-APR-02   R Maas            1.0.61
-- Changes for FS11_100                 14-JUN-02   R Maas            1.1.100
-- RGMA changes for 1.2.0               11-SEP-02   R Maas            1.2.0.1
-- Changes for 1.3.0                    06-DEC-02   R Maas            1.3.0.1
-- CCN 10000750                         24-MAR-03   K Taylor          2.0.0.1
-- RGMA Data Conversion                 25-MAR-03   K Taylor          2.0.0.2
-- Changes for 2.1.0                    16-MAY-03   R Maas            2.1.0.1
-- Changes for 3.0.0                    21-OCT-03   K Taylor          3.0.0.1
-- 3.0.0 correction                     24-NOV-03   K Taylor          3.0.0.2
-- Changes for 4.0.0 (incl 3.0.100)     01-JUN-04   S Brown           4.0.0.0
-- Changes for 5.0.0                    18-OCT-04   R Maas            5.0.0.1
-- More changes for 5.0.0               15-NOV-04   D Jarvis          5.0.0.2
-- Changes for FS520                    18-JUL-05   A Parker          5.2.0.0
-- RCNDT transaction_type_reason_code
-- insert added                         14-SEP-05   D Jarvis          5.2.0.1
-- FS820 Miscellaneous MIS820_8 ESL     02-JUN-09   A Cubbon          8.2.0.0    
-- SPAA 12_225 Changes			    25-MAR-13   C Brown		    10.0.002.0  
-- CCN10000560 GAS_METER_MECHANISM	    18-APR-13   C Brown		    10.0.002.1      
--------------------------------------------------------------------------------
--
PROMPT
PROMPT Script to create Cross Reference standing data for Job Manager
PROMPT
PROMPT Version 10.0.002.0     
PROMPT
--
/*******************/
/* CROSS_REFERENCE */
/*******************/
--
DELETE FROM CROSS_REFERENCE
WHERE ATTRIBUTE_NAME IN ('GAS_METER_MECHANISM')
/
--
--
/***********************/
/* GAS_METER_MECHANISM */
/***********************/
--
INSERT INTO CROSS_REFERENCE (ATTRIBUTE_NAME, SYSTEM_CODE, CODE_DESCRIPTION,
                             CREATED_USER_ID, CREATED_MARKET_PARTICIPANT, CREATED_DATE)
VALUES ('GAS_METER_MECHANISM', 'CR', 'Credit', USER, 'BSMART', SYSDATE)
/
--
INSERT INTO CROSS_REFERENCE (ATTRIBUTE_NAME, SYSTEM_CODE, CODE_DESCRIPTION,
                             CREATED_USER_ID, CREATED_MARKET_PARTICIPANT, CREATED_DATE)
VALUES ('GAS_METER_MECHANISM', 'ET', 'Electronic Token Meter', USER, 'BSMART', SYSDATE)
/
--
INSERT INTO CROSS_REFERENCE (ATTRIBUTE_NAME, SYSTEM_CODE, CODE_DESCRIPTION,
                             CREATED_USER_ID, CREATED_MARKET_PARTICIPANT, CREATED_DATE)
VALUES ('GAS_METER_MECHANISM', 'CM', 'Coin Meter', USER, 'BSMART', SYSDATE)
/
--
INSERT INTO CROSS_REFERENCE (ATTRIBUTE_NAME, SYSTEM_CODE, CODE_DESCRIPTION,
                             CREATED_USER_ID, CREATED_MARKET_PARTICIPANT, CREATED_DATE)
VALUES ('GAS_METER_MECHANISM', 'MT', 'Mechanical Token Meter', USER, 'BSMART', SYSDATE)
/
--
INSERT INTO CROSS_REFERENCE (ATTRIBUTE_NAME, SYSTEM_CODE, CODE_DESCRIPTION,
                             CREATED_USER_ID, CREATED_MARKET_PARTICIPANT, CREATED_DATE)
VALUES ('GAS_METER_MECHANISM', 'TH', 'Thrift', USER, 'BSMART', SYSDATE)
/
--
INSERT INTO CROSS_REFERENCE (ATTRIBUTE_NAME, SYSTEM_CODE, CODE_DESCRIPTION,
                             CREATED_USER_ID, CREATED_MARKET_PARTICIPANT, CREATED_DATE)
VALUES ('GAS_METER_MECHANISM', 'PP', 'Prepayment', USER, 'BSMART', SYSDATE)
/
--
INSERT INTO CROSS_REFERENCE (ATTRIBUTE_NAME, SYSTEM_CODE, CODE_DESCRIPTION,
                             CREATED_USER_ID, CREATED_MARKET_PARTICIPANT, CREATED_DATE)
VALUES ('GAS_METER_MECHANISM', 'U', 'Unknown', USER, 'BSMART', SYSDATE)
/
--
INSERT INTO CROSS_REFERENCE (ATTRIBUTE_NAME, SYSTEM_CODE, CODE_DESCRIPTION,
                             CREATED_USER_ID, CREATED_MARKET_PARTICIPANT, CREATED_DATE)
VALUES ('GAS_METER_MECHANISM', 'NS', 'Non Compliant SMETS Smart Meter', USER, 'BSMART', SYSDATE)
/
--
INSERT INTO CROSS_REFERENCE (ATTRIBUTE_NAME, SYSTEM_CODE, CODE_DESCRIPTION,
                             CREATED_USER_ID, CREATED_MARKET_PARTICIPANT, CREATED_DATE)
VALUES ('GAS_METER_MECHANISM', 'S1', 'SMETS 1 compliant Smart Meter', USER, 'BSMART', SYSDATE)
/
--
INSERT INTO CROSS_REFERENCE (ATTRIBUTE_NAME, SYSTEM_CODE, CODE_DESCRIPTION,
                             CREATED_USER_ID, CREATED_MARKET_PARTICIPANT, CREATED_DATE)
VALUES ('GAS_METER_MECHANISM', 'S2', 'SMETS 2 compliant Smart Meter', USER, 'BSMART', SYSDATE)
/
--
--
PROMPT Applying generis timestamp
--
UPDATE CROSS_REFERENCE
   SET LAST_UPDATE_USER_ID = 'GENERIS',
       LAST_UPDATE_DATE = TO_DATE('01010001', 'DDMMYYYY') + 002000.00
WHERE ATTRIBUTE_NAME IN ('GAS_METER_MECHANISM')
/
--
COMMIT
/

